@@ -919,7 +919,7 @@ typedef void 			(*wan_taskq_func_t)(struct work_struct *);
 typedef struct tq_struct 	wan_taskq_t;
 
 typedef void*			virt_addr_t;
-typedef unsigned long		phys_addr_t;
+typedef unsigned long		wp_phys_addr_t;
 typedef spinlock_t		wan_spinlock_t;
 typedef rwlock_t		wan_rwlock_t;
 typedef unsigned long		wan_smp_flag_t;
@@ -950,7 +950,7 @@ typedef void*			wan_timer_arg_t;
 typedef task_fn_t		wan_tasklet_func_t;
 typedef task_fn_t*		wan_taskq_func_t;
 typedef caddr_t			virt_addr_t;
-typedef u_int32_t		phys_addr_t;
+typedef u_int32_t		wp_phys_addr_t;
 typedef int			atomic_t;
 typedef dev_t			ttydriver_t;
 typedef struct tty		ttystruct_t;
@@ -987,7 +987,7 @@ typedef void*			wan_timer_arg_t;
 typedef void 			wan_tasklet_func_t(void*, int);
 typedef void 			(*wan_taskq_func_t)(void*, int);
 typedef caddr_t			virt_addr_t;
-typedef u_int32_t		phys_addr_t;
+typedef u_int32_t		wp_phys_addr_t;
 typedef int			atomic_t;
 typedef dev_t			ttydriver_t;
 typedef struct tty		ttystruct_t;
@@ -1014,7 +1014,7 @@ typedef void*			wan_timer_arg_t;
 typedef void 			wan_tasklet_func_t(void*, int);
 typedef void 			(*wan_taskq_func_t)(void*, int);
 typedef caddr_t			virt_addr_t;
-typedef u_int32_t		phys_addr_t;
+typedef u_int32_t		wp_phys_addr_t;
 typedef int			atomic_t;
 typedef dev_t			ttydriver_t;
 typedef struct tty		ttystruct_t;
