@@ -558,7 +558,7 @@ static int sdla_56k_udp(sdla_fe_t *fe, void* pudp_cmd, unsigned char* data)
 	    	udp_cmd->wan_cmd_data_len = sizeof(sdla_fe_stats_t);
 		break;
 
-	case WAN_FE_SET_LB_MODE:
+	case WAN_FE_LB_MODE:
 		/* Activate/Deactivate Line Loopback modes */
 	    	err = sdla_56k_set_lbmode(fe, data[0], data[1]); 
 	    	udp_cmd->wan_cmd_return_code = 
