@@ -60,6 +60,8 @@
 
 #define OHT_TIMER		6000	/* How long after RING to retain OHT */
 
+#define FXO_LINK_DEBOUNCE	200
+
 #define MAX_ALARMS		10
 
 /* Interrupt flag enable */
@@ -711,6 +713,32 @@ static void wp_tdmv_remora_voicedaa_check_hook(wp_tdmv_remora_t *wr, int mod_no)
 	}
 #endif	
 
+	if (abs(b) <= 1){
+		fe->rm_param.mod[mod_no].u.fxo.statusdebounce ++;
+		if (fe->rm_param.mod[mod_no].u.fxo.statusdebounce >= FXO_LINK_DEBOUNCE){
+			if (fe->rm_param.mod[mod_no].u.fxo.status != FE_DISCONNECTED){
+				DEBUG_EVENT(
+				"%s: Module %d: FXO Line is disconnnected!\n",
+								wr->devname,
+								mod_no + 1);
+				fe->rm_param.mod[mod_no].u.fxo.status = FE_DISCONNECTED;
+			}
+			fe->rm_param.mod[mod_no].u.fxo.statusdebounce = FXO_LINK_DEBOUNCE;
+		}
+	}else{
+		fe->rm_param.mod[mod_no].u.fxo.statusdebounce--;
+		if (fe->rm_param.mod[mod_no].u.fxo.statusdebounce <= 0) {
+			if (fe->rm_param.mod[mod_no].u.fxo.status != FE_CONNECTED){
+				DEBUG_EVENT(
+				"%s: Module %d: FXO Line is connected!\n",
+								wr->devname,
+								mod_no + 1);
+				fe->rm_param.mod[mod_no].u.fxo.status = FE_CONNECTED;
+			}
+			fe->rm_param.mod[mod_no].u.fxo.statusdebounce = 0;
+		}
+	}
+
 	if (abs(b) < wr->battthresh) {
 		wr->mod[mod_no].fxo.nobatttimer++;
 #if 0
