@@ -789,7 +789,7 @@ static int sdla_te3_udp(sdla_fe_t *fe, void *pudp_cmd, unsigned char *data)
 		udp_cmd->wan_cmd_data_len = sizeof(unsigned char); 
 		break;
 
-	case WAN_FE_SET_LB_MODE:
+	case WAN_FE_LB_MODE:
 		/* Activate/Deactivate Line Loopback modes */
 		if (card->adptr_subtype == AFT_SUBTYPE_NORMAL){
 			err = sdla_te3_old_set_lb_modes(fe, data[0], data[1]); 
