@@ -777,7 +777,14 @@ static ssize_t wp_tdmapi_write_msg(struct file *file, struct msghdr *msg, size_t
 			return -EINVAL;
 		}
 #endif
-		skb_len=WP_TDM_API_MAX_LEN;
+
+		if (count > (WP_TDM_API_MAX_LEN+sizeof(wp_tdm_api_tx_hdr_t))) {
+			DEBUG_TEST("%s: Error: TDM API Tx packet too big %d\n",
+				tdm_api->name,count);
+			return -EFBIG;
+		}
+
+		skb_len=WP_TDM_API_MAX_LEN+sizeof(wp_tdm_api_tx_hdr_t);
 	}
 
 	DEBUG_TEST("%s: TX FRAME List=%i\n",
