@@ -70,6 +70,11 @@
 #define MAXPENDING 500
 #define MGD_STACK_SIZE 1024 * 240
 
+#define SMG_SOCKET_EVENT_DATA	1
+#define SMG_SOCKET_EVENT_OOB	2
+#define SMG_SOCKET_EVENT_TIMEOUT 0
+#define SMG_SOCKET_EVENT_ERR	-1
+#define SMG_SOCKET_EVENT_NVAL	-2
 
 typedef enum {
     WFLAG_RUNNING 		= (1 << 0),
@@ -159,6 +164,7 @@ struct media_session {
     int skip_read_frames;
     int skip_write_frames;
     int hw_coding;
+    int hw_dtmf;
     int udp_sync_cnt;
     
 #ifdef WP_HPTDM_API
@@ -277,6 +283,7 @@ struct woomera_server {
     	int dtmf_intr_ch;
     	int dtmf_size;
 	int strip_cid_non_digits;
+	int udp_seq;
 } server;
 
 struct woomera_config {
