@@ -761,7 +761,7 @@ static int init(int argc, char *argv[], char* command)
 #endif
 
 
-	for (i = 0; i < argc; i++){
+	for (i = 1; i < argc; i++){
 		if (!strcmp(argv[i],"-h")){
 #if defined(CONFIG_PRODUCT_WANPIPE_GENERIC)
 			EXEC_NAME_FUNC(usage,"hdlc",());
@@ -814,6 +814,7 @@ static int init(int argc, char *argv[], char* command)
 		}else if (!strcmp(argv[i],"-zap")){
 			zap_monitor=1;
 			wan_protocol = WANCONFIG_ZAP;
+
 		
 		}else if (!strcmp(argv[i],"-zapchan")){
 			if (i+1 > argc-1){
@@ -914,6 +915,15 @@ static int init(int argc, char *argv[], char* command)
 		
 		}else if (!strcmp(argv[i], "-systime")){
 			sys_timestamp=1;
+		
+		}else if (!strcmp(argv[i], "-mtp2-all")){
+			mtp2_msu_only=0;
+			printf("MTP2 Trace All\n"); 
+		}else if (!strcmp(argv[i], "-7bit-hdlc")){
+			if (rx_hdlc_eng) {
+				rx_hdlc_eng->seven_bit_hdlc = 1;	
+				printf("Enabling 7bit HDLC\n");
+			}
 
 		}else if (!strcmp(argv[i], "-prot")){
 			int x;
@@ -1004,7 +1014,7 @@ static int init(int argc, char *argv[], char* command)
 					       progname);
 				exit(1);
 			}
-		}
+		} 
 	}
 
 #ifdef WANPIPEMON_ZAP
@@ -1241,7 +1251,7 @@ static unsigned char trace_info[]="\n"
 "				# eg: -prot LAPB-X25\n"
 "				#Default: All frames\n"
 "\n"
-"		[FR|PPP|CHDLC|IP|ETH|LAPB|X25]\n"
+"		[ISDN|MTP2|FR|PPP|CHDLC|IP|ETH|LAPB|X25]\n"
 "				#Also used by -pcap option to\n"
 "				#specify what protocol we are\n"
 "				#capturing. By default protocol is\n"
@@ -1275,7 +1285,11 @@ static unsigned char trace_info[]="\n"
 "\n"
 "	-systime		#Display timestamp as system time\n"
 "	                        #instead of absolute number\n"
-"	\n"
+"\n"
+"	-mtp2-all		#Trace full MTP2 layer FISU/LSSU/MSU\n"
+"\n"
+"	-7bit-hdlc		#Decode hdlc stream as 7bit instead of 8bit\n"
+"\n"
 "	-full			#Display packet data in full.\n"
 "\n"
 "Examples:\n"
@@ -1300,7 +1314,15 @@ static unsigned char trace_info[]="\n"
 "\n"
 "  wanpipemon -i wan0 -pcap -c tr\n"
 "  wanpipemon -i wan0 -pcap -pcap_file myfile.bin -c tr\n"
-"  wanpipemon -i wan0 -pcap -prot FRAME -c tr\n\n";
+"  wanpipemon -i wan0 -pcap -prot FRAME -c tr\n"
+"\n"
+"#Trace ISDN/MTP2 data to a pcap type file\n"
+"  wanpipemon -i w1g1 -pcap -pcap_file isdn.pcap -prot ISDN -full -systime -c trd\n"
+"  wanpipemon -i w1g1 -pcap -pcap_file isdn.pcap -prot ISDN -pcap_isdn_network  -full -systime -c trd"
+"\n"
+"  wanpipemon -i w1g1 -pcap -pcap_file mtp2.pcap -prot MTP2 -full -systime -c trh"
+"\n"
+"\n";
 
 static void usage_trace_info(void)
 {
